instrumenttools.Viola
=====================

.. abjad-lineage:: abjad.tools.instrumenttools.Viola.Viola.Viola

.. autoclass:: abjad.tools.instrumenttools.Viola.Viola.Viola
   :noindex:

Read-only Properties
--------------------

.. autoattribute:: abjad.tools.instrumenttools.Viola.Viola.Viola.default_instrument_name
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.Viola.Viola.Viola.default_short_instrument_name
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.Viola.Viola.Viola.effective_context
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.Viola.Viola.Viola.interval_of_transposition
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.Viola.Viola.Viola.is_primary_instrument
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.Viola.Viola.Viola.is_secondary_instrument
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.Viola.Viola.Viola.is_transposing
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.Viola.Viola.Viola.lilypond_format
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.Viola.Viola.Viola.start_component
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.Viola.Viola.Viola.storage_format
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.Viola.Viola.Viola.target_context
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.Viola.Viola.Viola.traditional_pitch_range
   :noindex:

Read/write Properties
---------------------

.. autoattribute:: abjad.tools.instrumenttools.Viola.Viola.Viola.all_clefs
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.Viola.Viola.Viola.instrument_name
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.Viola.Viola.Viola.instrument_name_markup
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.Viola.Viola.Viola.pitch_range
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.Viola.Viola.Viola.primary_clefs
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.Viola.Viola.Viola.short_instrument_name
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.Viola.Viola.Viola.short_instrument_name_markup
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.Viola.Viola.Viola.sounding_pitch_of_fingered_middle_c
   :noindex:

Methods
-------

.. automethod:: abjad.tools.instrumenttools.Viola.Viola.Viola.attach
   :noindex:

.. automethod:: abjad.tools.instrumenttools.Viola.Viola.Viola.detach
   :noindex:

.. automethod:: abjad.tools.instrumenttools.Viola.Viola.Viola.get_default_performer_name
   :noindex:

.. automethod:: abjad.tools.instrumenttools.Viola.Viola.Viola.get_performer_names
   :noindex:

Special Methods
---------------

.. automethod:: abjad.tools.instrumenttools.Viola.Viola.Viola.__call__
   :noindex:

.. automethod:: abjad.tools.instrumenttools.Viola.Viola.Viola.__delattr__
   :noindex:

.. automethod:: abjad.tools.instrumenttools.Viola.Viola.Viola.__eq__
   :noindex:

.. automethod:: abjad.tools.instrumenttools.Viola.Viola.Viola.__ge__
   :noindex:

.. automethod:: abjad.tools.instrumenttools.Viola.Viola.Viola.__gt__
   :noindex:

.. automethod:: abjad.tools.instrumenttools.Viola.Viola.Viola.__hash__
   :noindex:

.. automethod:: abjad.tools.instrumenttools.Viola.Viola.Viola.__le__
   :noindex:

.. automethod:: abjad.tools.instrumenttools.Viola.Viola.Viola.__lt__
   :noindex:

.. automethod:: abjad.tools.instrumenttools.Viola.Viola.Viola.__ne__
   :noindex:

.. automethod:: abjad.tools.instrumenttools.Viola.Viola.Viola.__repr__
   :noindex:
